compose

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 5, 2025 License: MIT Imports: 18 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewComposeDownCommand

func NewComposeDownCommand(container *di.Container) *cobra.Command

NewComposeDownCommand creates a new cobra command for compose down.

func NewComposeInitCommand

func NewComposeInitCommand(_ *di.Container) *cobra.Command

NewComposeInitCommand creates a new cobra command for compose init.

func NewComposeLogsCommand

func NewComposeLogsCommand(container *di.Container) *cobra.Command

NewComposeLogsCommand creates a new cobra command for retrieving and displaying function logs.

func NewComposeUpCommand

func NewComposeUpCommand(container *di.Container) *cobra.Command

Types

This section is empty.

Jump to